# Stencils - Python package for template files 

[![PyPI - Version](https://img.shields.io/pypi/v/stencils?style=for-the-badge)](https://pypi.org/project/consolio)
![PyPI - Python Version](https://img.shields.io/pypi/pyversions/stencils?style=for-the-badge)
![GitHub License](https://img.shields.io/github/license/devcoons/stencils?style=for-the-badge)
![PyPI - Wheel](https://img.shields.io/pypi/wheel/stencils?style=for-the-badge&color=%23F0F)
